OpmlItem class

Constructors

OpmlItem({String? title, String? text, String? description, String? type, String? version, String? xmlUrl, String? htmlUrl, String? language, List<OpmlItem>? nesteditems})
OpmlItem.parse(XmlNode element)
factory
OpmlItem.parseWithoutNested(XmlNode element)
factory

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
htmlUrl → String?
final
language → String?
final
nesteditems → List<OpmlItem>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final
title → String?
final
type → String?
final
version → String?
final
xmlUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited